@@ -6,6 +6,7 @@
 #' @param low_eqbound lower equivalence bounds (e.g., -0.1) expressed in proportions
 #' @param high_eqbound upper equivalence bounds (e.g., 0.1) expressed in proportions
 #' @param alpha alpha level (default = 0.05)
+#' @param ci_type confidence interval type (default = "normal"). "wilson" produces Wilson score intervals with a Yates continuity correction while "normal" calculates the simple asymptotic method with no continuity correction.
 #' @param plot set whether results should be plotted (plot = TRUE) or not (plot = FALSE) - defaults to TRUE
 #' @param verbose logical variable indicating whether text output should be generated (verbose = TRUE) or not (verbose = FALSE) - default to TRUE
 #' @return Returns TOST z-value 1, TOST p-value 1, TOST z-value 2, TOST p-value 2, low equivalence bound, high equivalence bound, Lower limit confidence interval TOST, Upper limit confidence interval TOST
@@ -23,7 +24,7 @@
 #' Yin, G. (2012). Clinical Trial Design: Bayesian and Frequentist Adaptive Methods. Hoboken, New Jersey: John Wiley & Sons, Inc.
 #' @export
 
-TOSTtwo.prop <- function(prop1, prop2, n1, n2, low_eqbound, high_eqbound, alpha, plot = TRUE, verbose = TRUE) {
+TOSTtwo.prop <- function(prop1, prop2, n1, n2, low_eqbound, high_eqbound, alpha, ci_type = "normal", plot = TRUE, verbose = TRUE) {
   if(missing(alpha)) {
     alpha <- 0.05
   }
@@ -32,8 +33,10 @@ TOSTtwo.prop <- function(prop1, prop2, n1, n2, low_eqbound, high_eqbound, alpha,
   if(1 <= alpha | alpha <= 0) stop("The alpha level should be a positive value between 0 and 1.")
   if(1 < prop1 | prop1 < 0) stop("The proportion should be a positive value between 0 and 1.")
   if(1 < prop2 | prop2 < 0) stop("The proportion should be a positive value between 0 and 1.")
+  if(ci_type != "normal" & ci_type != "wilson") stop("ci_type must be equal to wilson or normal")
 
     prop_dif <- prop1 - prop2
+  # proportion se
   prop_se <- sqrt((prop1*(1-prop1))/n1 + (prop2*(1-prop2))/n2)
 
   #calculating z-statistic
@@ -49,12 +52,32 @@ TOSTtwo.prop <- function(prop1, prop2, n1, n2, low_eqbound, high_eqbound, alpha,
   ztost <- ifelse(abs(z1) < abs(z2), z1, z2) #Get lowest z-value for summary TOST result
   TOSToutcome <- ifelse(ptost<alpha,"significant","non-significant")
   testoutcome <- ifelse(ztest<(alpha/2), "significant","non-significant")
+  # Wilson CI method
+  conf.level = 1 - alpha
+  DELTA = prop_dif
+  ESTIMATE = c(p1, p2)
+  YATES <- abs(DELTA) / sum(1 / n1, 1 / n2)
+  n = c(n1,n2)
+  WIDTH90 <- qnorm(conf.level) * sqrt(sum(ESTIMATE * (1 - ESTIMATE) / n)) + YATES * sum(1 / n)
+  WIDTH95 <- (qnorm((1+conf.level)/2))* sqrt(sum(ESTIMATE * (1 - ESTIMATE) / n)) + YATES * sum(1 / n)
+  CINT90 <- c(max(DELTA - WIDTH90, -1), min(DELTA + WIDTH90, 1))
+  CINT95 <- c(max(DELTA - WIDTH95, -1), min(DELTA + WIDTH95, 1))
 
   #calculating CIs
-  LL90 <- prop_dif - (qnorm(1-alpha) * prop_se)
-  UL90 <- prop_dif + (qnorm(1-alpha) * prop_se)
-  LL95 <- prop_dif - (qnorm(1-(alpha/2)) * prop_se)
-  UL95 <- prop_dif + (qnorm(1-(alpha/2)) * prop_se)
+  if(ci_type == "normal"){
+    LL90 <- prop_dif - (qnorm(1-alpha) * prop_se)
+    UL90 <- prop_dif + (qnorm(1-alpha) * prop_se)
+    LL95 <- prop_dif - (qnorm(1-(alpha/2)) * prop_se)
+    UL95 <- prop_dif + (qnorm(1-(alpha/2)) * prop_se)
+  }
+
+  if(ci_type == "wilson"){
+    LL90 <- CINT90[1]
+    UL90 <- CINT90[2]
+    LL95 <- CINT95[1]
+    UL95 <- CINT95[2]
+  }
+
 
   #plot results
   if (plot == TRUE) {
@@ -96,19 +119,26 @@ TOSTtwo.prop <- function(prop1, prop2, n1, n2, low_eqbound, high_eqbound, alpha,
     cat("Null-Hypothesis Fisher's exact z-test Result:\n")
     message(cat("The null hypothesis test was ",testoutcome,", Z = ",format(z, digits = 3, nsmall = 3, scientific = FALSE),", p = ",format((ztest * 2), digits = 3, nsmall = 3, scientific = FALSE),", given an alpha of ",alpha,".",sep=""))
     if((ztest * 2) <= alpha && ptost <= alpha){
-      combined_outcome <- "statistically different from zero and statistically equivalent to zero"
+      combined_outcome <- paste0("NHST: reject null significance hypothesis\n",
+                                 "TOST: reject null equivalence hypothesis")
+      #"statistically different from zero and statistically equivalent to zero"
     }
     if((ztest * 2) < alpha && ptost > alpha){
-      combined_outcome <- "statistically different from zero and statistically not equivalent to zero"
+      combined_outcome <- paste0("NHST: reject null significance hypothesis \n",
+                                 "TOST: don't reject null equivalence hypothesis")
+      #"statistically different from zero and statistically not equivalent to zero"
     }
     if((ztest * 2) > alpha && ptost <= alpha){
-      combined_outcome <- "statistically not different from zero and statistically equivalent to zero"
+      combined_outcome <- paste0("NHST: don't reject null significance hypothesis that the effect is equal to ",0," \n",
+                                 "TOST: reject null equivalence hypothesis")
+      #"statistically not different from zero and statistically equivalent to zero"
     }
     if((ztest * 2) > alpha && ptost > alpha){
-      combined_outcome <- "statistically not different from zero and statistically not equivalent to zero"
+      combined_outcome <- paste0("NHST: don't reject null significance hypothesis that the effect is equal to ",0," \n",
+                                 "TOST: don't reject null equivalence hypothesis")#"statistically not different from zero and statistically not equivalent to zero"
     }
     cat("\n")
-    message(cat("Based on the equivalence test and the null-hypothesis test combined, we can conclude that the observed effect is ",combined_outcome,".",sep=""))
+    message(combined_outcome)
   }
   # Return results in list()
   invisible(list(dif = prop_dif, TOST_z1 = z1, TOST_p1 = p1,TOST_z2 = z2,TOST_p2 = p2, alpha = alpha, low_eqbound = low_eqbound, high_eqbound = high_eqbound, LL_CI_TOST = LL90, UL_CI_TOST = UL90, LL_CI_ZTEST = LL95, UL_CI_ZTEST = UL95, NHST_z = z, NHST_p = (ztest * 2)))
