@@ -8,7 +8,7 @@ library(ggplot2)
 library(ggdist)
 
 
-## ----echo=FALSE, message = FALSE, warning = FALSE, fig.show='hold'------------
+## ----tostplots,echo=FALSE, message = FALSE, warning = FALSE, fig.show='hold'----
 
 ggplot() +
   geom_vline(aes(xintercept = -.5),
@@ -141,13 +141,12 @@ head(sleep)
 ## -----------------------------------------------------------------------------
 res1 = t_TOST(formula = extra ~ group,
               data = sleep,
-              low_eqbound = -.5,
-              high_eqbound = .5)
+              eqb = .5,
+              smd_ci = "goulet")
 
 res1a = t_TOST(x = subset(sleep,group==1)$extra,
                y = subset(sleep,group==2)$extra,
-               low_eqbound = -.5,
-               high_eqbound = .5)
+               eqb = .5)
 
 ## -----------------------------------------------------------------------------
 print(res1)
@@ -155,9 +154,10 @@ print(res1)
 ## ----fig.width=6, fig.height=6------------------------------------------------
 plot(res1, type = "cd")
 
-## ----fig.width=6, fig.height=6------------------------------------------------
-plot(res1, type = "cd",
-     ci_shades = c(.9,.95))
+## ----fig.width=6, fig.height=6, eval=FALSE------------------------------------
+#  # Set to shade only the 90% and 95% CI areas
+#  plot(res1, type = "cd",
+#       ci_shades = c(.9,.95))
 
 ## ----fig.width=6, fig.height=6------------------------------------------------
 plot(res1, type = "c",
@@ -167,16 +167,14 @@ plot(res1, type = "c",
 res2 = t_TOST(formula = extra ~ group,
               data = sleep,
               paired = TRUE,
-              low_eqbound = -.5,
-              high_eqbound = .5)
+              eqb = .5)
 res2
 
 ## -----------------------------------------------------------------------------
 res3 = t_TOST(x = iris$Sepal.Length,
               y = iris$Sepal.Width,
               paired = TRUE,
-              low_eqbound = -1,
-              high_eqbound = 1)
+              eqb = 1)
 res3
 
 ## -----------------------------------------------------------------------------
@@ -184,31 +182,24 @@ res3a = t_TOST(x = iris$Sepal.Length,
               y = iris$Sepal.Width,
                paired = TRUE,
                hypothesis = "MET",
-               low_eqbound = -1,
-               high_eqbound = 1)
+               eqb = 1,
+              smd_ci = "goulet")
 res3a
 
-## ----fig.width=6, fig.height=6------------------------------------------------
-plot(res3a)
-
 ## -----------------------------------------------------------------------------
 res4 = t_TOST(x = iris$Sepal.Length,
               hypothesis = "EQU",
-              low_eqbound = 5.5,
-              high_eqbound = 8.5)
+              eqb = c(5.5,8.5),
+              smd_ci = "goulet")
 res4
 
-## ----fig.width=6, fig.height=6------------------------------------------------
-plot(res4)
-
 ## -----------------------------------------------------------------------------
 res_tsum = tsum_TOST(
   m1 = mean(iris$Sepal.Length, na.rm=TRUE),
   sd1 = sd(iris$Sepal.Length, na.rm=TRUE),
   n1 = length(na.omit(iris$Sepal.Length)),
   hypothesis = "EQU",
-  low_eqbound = 5.5,
-  high_eqbound = 8.5
+  eqb = c(5.5,8.5)
 )
 
 res_tsum
@@ -220,8 +211,7 @@ plot(res_tsum)
 power_t_TOST(n = NULL,
   delta = 1,
   sd = 2.5,
-  low_eqbound = -2.5,
-  high_eqbound = 2.5,
+  eqb = 2.5,
   alpha = .025,
   power = .95,
   type = "two.sample")
